import{d as u,ez as b,H as f,b as y,c as g,u as _}from"./outputWidgets.8be138ba.js";import{a as w}from"./asyncComputed.96c9ad3b.js";import"./router.bb47648a.js";import{M as n}from"./member.69d04c1f.js";import"./columns.5510282a.js";import{C as I}from"./CrudView.cfa43f1a.js";import"./Title.12e8916a.js";import"./index.0df733bd.js";import"./gateway.93fa1934.js";import"./activeRecord.f6cce158.js";import"./pubsub.e324f67c.js";import"./index.f4ac7424.js";import"./icons.35976e57.js";import"./index.98827a3d.js";import"./Form.7b75db7b.js";import"./url.ebe1e528.js";import"./index.3ef3e2d2.js";import"./index.bc7e7ec9.js";import"./index.d11a75f6.js";import"./index.568a8efe.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="5ad2ed52-5001-4c29-b76f-0c79365405b7",e._sentryDebugIdIdentifier="sentry-dbid-5ad2ed52-5001-4c29-b76f-0c79365405b7")}catch{}})();const G=u({__name:"Members",setup(e){const r=b().params.organizationId,m=[{key:"email",label:"Email"}],s=async t=>{await n.create(r,t.email),p()},{loading:l,result:d,refetch:p}=w(()=>n.list(r)),c=f(()=>{var t,a;return{columns:[{name:"Email"},{name:"Role"}],rows:(a=(t=d.value)==null?void 0:t.map(i=>({key:i.email,cells:[{text:i.email},{text:i.role}]})))!=null?a:[]}});return(t,a)=>(y(),g(I,{"entity-name":"members",loading:_(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:c.value,"create-button-text":"Add members",fields:m,onCreate:s},null,8,["loading","table"]))}});export{G as default};
//# sourceMappingURL=Members.0ff6e912.js.map
