import{d as b,ey as y,H as h,b as g,c as w,u as _}from"./outputWidgets.8be138ba.js";import{e as C,a as F,b as k}from"./icons.35976e57.js";import{a as x}from"./asyncComputed.96c9ad3b.js";import{F as l}from"./forms.435a25a3.js";import{C as v}from"./CrudView.cfa43f1a.js";import{a as D}from"./ant-design.e9f581dc.js";import"./activeRecord.f6cce158.js";import"./pubsub.e324f67c.js";import"./index.98827a3d.js";import"./Title.12e8916a.js";import"./Form.7b75db7b.js";import"./router.bb47648a.js";import"./index.0df733bd.js";import"./url.ebe1e528.js";import"./index.3ef3e2d2.js";import"./index.bc7e7ec9.js";import"./index.d11a75f6.js";import"./index.568a8efe.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[r]="be0cc5e8-085b-400e-8cea-394911a49cb2",a._sentryDebugIdIdentifier="sentry-dbid-be0cc5e8-085b-400e-8cea-394911a49cb2")}catch{}})();const z=b({__name:"Forms",setup(a){const r=y(),{loading:s,result:n,refetch:c}=x(()=>l.list()),m=({key:e})=>r.push({path:`/_editor/form/${encodeURIComponent(e)}`}),d=async({key:e})=>{var o,t;await((t=(o=n.value)==null?void 0:o.find(i=>i.path===e))==null?void 0:t.duplicate()),c()},p=async()=>{const e=await l.create();m({key:e.path})},u=async({key:e})=>{var o,t;await D("Are you sure you want to delete this form?")&&(await((t=(o=n.value)==null?void 0:o.find(i=>i.path===e))==null?void 0:t.delete()),c())},f=h(()=>{var e,o;return{columns:[{name:"Form Name"},{name:"Path"},{name:"Actions",align:"right"}],rows:(o=(e=n.value)==null?void 0:e.map(t=>({key:t.path,cells:[{text:t.title,link:`/_editor/form/${encodeURIComponent(t.path)}`},{text:t.path},{text:"",actions:[{icon:C,label:"Edit Form",onClick:m},{icon:F,label:"Duplicate",onClick:d},{icon:k,label:"Delete",onClick:u,dangerous:!0}]}]})))!=null?o:[]}});return(e,o)=>(g(),w(v,{loading:_(s),title:"Dynamic Python forms",description:"Create forms with advanced logic, easy integrations and custom branding.","create-button-text":"Create Form","empty-title":"No forms here yet","video-url":"https://www.youtube.com/embed/p6xf8PxL2Yg",table:f.value,"entity-name":"Form",onCreate:p},null,8,["loading","table"]))}});export{z as default};
//# sourceMappingURL=Forms.98b29f46.js.map
