import{v as a}from"./icons.35976e57.js";import{d as c,a as r,b as f,et as d,f as i,u as _,aI as l,v as u}from"./outputWidgets.8be138ba.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="64fdf8c8-3f5c-4ff7-80ed-73fc11147c83",e._sentryDebugIdIdentifier="sentry-dbid-64fdf8c8-3f5c-4ff7-80ed-73fc11147c83")}catch{}})();const p=c({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const s=r("icon");return f(),d("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[i(s,{class:"icon",path:_(a),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),l(" Editor ")])}}});const v=u(p,[["__scopeId","data-v-eaeb3a6e"]]);export{v as B};
//# sourceMappingURL=BackButton.511a86a5.js.map
