import{d as g,ey as v,ez as k,r as b,b as r,c as s,w as a,u as e,f as u,ev as n}from"./outputWidgets.8be138ba.js";import{S as j,L as w}from"./SmartConsole.8b980989.js";import{a as x}from"./asyncComputed.96c9ad3b.js";import{J as I}from"./jobs.abbd52e0.js";import{_ as B}from"./SaveButton.vue_vue_type_script_setup_true_lang.c3b85166.js";import{_ as C}from"./DocsButton.vue_vue_type_script_setup_true_lang.425c079f.js";import{B as S}from"./BaseLayout.7e0231be.js";import{_ as T,a as D}from"./JobSettings.vue_vue_type_script_setup_true_lang.0c11df8a.js";import{c as R}from"./index.7e655723.js";import{A as _,T as $}from"./TabPane.03183a8f.js";import"./forms.435a25a3.js";import"./activeRecord.f6cce158.js";import"./pubsub.e324f67c.js";import"./dashes.e479dfed.js";import"./runnerData.48ddf2c0.js";import"./hooks.f815923f.js";import"./workspaces.69791308.js";import"./url.ebe1e528.js";import"./icons.35976e57.js";import"./Title.12e8916a.js";import"./index.bc7e7ec9.js";import"./uuid.3f13542a.js";import"./ant-design.e9f581dc.js";import"./RunButton.vue_vue_type_script_setup_true_lang.b0a1be8e.js";import"./index.c72b88ec.js";import"./index.3ef3e2d2.js";import"./dayjs.68ea0cd7.js";import"./Form.7b75db7b.js";import"./index.568a8efe.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[m]="5803f9b3-43fb-4d39-a747-c4660b463536",i._sentryDebugIdIdentifier="sentry-dbid-5803f9b3-43fb-4d39-a747-c4660b463536")}catch{}})();const me=g({__name:"JobEditor",setup(i){const m=v(),l=k(),f=b(null),o=b("test");function y(){m.push({name:"jobs"})}const{result:t}=x(()=>I.get(l.params.jobId)),c=w.create();return(A,d)=>(r(),s(S,null,{navbar:a(()=>[e(t)?(r(),s(e(R),{key:0,title:e(t).title,style:{padding:"5px 10px"},onBack:y},{footer:a(()=>[u(e($),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=p=>o.value=p)},{default:a(()=>[u(e(_),{key:"test",tab:"Test"}),u(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[u(C),o.value==="settings"?(r(),s(B,{key:0,model:e(t)},null,8,["model"])):n("",!0)]),_:1},8,["title"])):n("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(T,{key:0,ref_key:"tester",ref:f,job:e(t),"log-service":e(c)},null,8,["job","log-service"])):n("",!0),e(t)&&o.value==="settings"?(r(),s(D,{key:1,job:e(t)},null,8,["job"])):n("",!0)]),footer:a(()=>{var p;return[e(t)&&o.value==="test"?(r(),s(j,{key:0,runtime:"forms","log-service":e(c),onRestart:(p=f.value)==null?void 0:p.test},null,8,["log-service","onRestart"])):n("",!0)]}),_:1}))}});export{me as default};
//# sourceMappingURL=JobEditor.606f9b41.js.map
