import{d as g,ey as v,ez as b,r as k,b as r,c as s,w as a,u as e,f as c,ev as n}from"./outputWidgets.8be138ba.js";import{S as h,L as w}from"./SmartConsole.8b980989.js";import{a as x}from"./asyncComputed.96c9ad3b.js";import{H as B}from"./hooks.f815923f.js";import{_ as C}from"./SaveButton.vue_vue_type_script_setup_true_lang.c3b85166.js";import{_ as H}from"./DocsButton.vue_vue_type_script_setup_true_lang.425c079f.js";import{B as I}from"./BaseLayout.7e0231be.js";import{_ as S,a as T}from"./HookSettings.vue_vue_type_script_setup_true_lang.ebb3a328.js";import{c as D}from"./index.7e655723.js";import{A as _,T as R}from"./TabPane.03183a8f.js";import"./forms.435a25a3.js";import"./activeRecord.f6cce158.js";import"./pubsub.e324f67c.js";import"./dashes.e479dfed.js";import"./runnerData.48ddf2c0.js";import"./jobs.abbd52e0.js";import"./workspaces.69791308.js";import"./url.ebe1e528.js";import"./icons.35976e57.js";import"./Title.12e8916a.js";import"./index.bc7e7ec9.js";import"./uuid.3f13542a.js";import"./ant-design.e9f581dc.js";import"./StageRunSelector.vue_vue_type_script_setup_true_lang.d90a4e55.js";import"./RunButton.vue_vue_type_script_setup_true_lang.b0a1be8e.js";import"./index.015c51a8.js";import"./index.d11a75f6.js";import"./CollapsePanel.cd9ccb4b.js";import"./index.568a8efe.js";import"./index.ea292f7a.js";import"./index.3ef3e2d2.js";import"./Form.7b75db7b.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[m]="d2d87c15-e9c8-4148-81c6-2c92fc57ed3f",i._sentryDebugIdIdentifier="sentry-dbid-d2d87c15-e9c8-4148-81c6-2c92fc57ed3f")}catch{}})();const ue=g({__name:"HookEditor",setup(i){const m=v(),u=b(),l=k(null),o=k("test");function y(){m.push({name:"hooks"})}const{result:t}=x(()=>B.get(u.params.hookPath)),f=w.create();return($,d)=>(r(),s(I,null,{navbar:a(()=>[e(t)?(r(),s(e(D),{key:0,title:e(t).title,style:{padding:"5px 10px"},onBack:y},{footer:a(()=>[c(e(R),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=p=>o.value=p)},{default:a(()=>[c(e(_),{key:"test",tab:"Test"}),c(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[c(H,{path:"hooks"}),o.value==="settings"?(r(),s(C,{key:0,model:e(t)},null,8,["model"])):n("",!0)]),_:1},8,["title"])):n("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(S,{key:0,ref_key:"tester",ref:l,hook:e(t),"log-service":e(f)},null,8,["hook","log-service"])):n("",!0),e(t)&&o.value==="settings"?(r(),s(T,{key:1,hook:e(t)},null,8,["hook"])):n("",!0)]),footer:a(()=>{var p;return[e(t)&&o.value==="test"?(r(),s(h,{key:0,runtime:"forms","log-service":e(f),onRestart:(p=l.value)==null?void 0:p.runHook},null,8,["log-service","onRestart"])):n("",!0)]}),_:1}))}});export{ue as default};
//# sourceMappingURL=HookEditor.d1c43f57.js.map
