import{C as n,A as t}from"./CollapsePanel.cd9ccb4b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="860afa33-135f-4752-844b-f8d9946d40b6",e._sentryDebugIdIdentifier="sentry-dbid-860afa33-135f-4752-844b-f8d9946d40b6")}catch{}})();n.Panel=t;n.install=function(e){return e.component(n.name,n),e.component(t.name,t),e};
//# sourceMappingURL=index.f0b80fab.js.map
