import"./outputWidgets.8be138ba.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="af80099b-3a9e-4f5f-9404-78b73ea7c71e",e._sentryDebugIdIdentifier="sentry-dbid-af80099b-3a9e-4f5f-9404-78b73ea7c71e")}catch{}})();function s(e){return e.charAt(0).toUpperCase()+e.slice(1)}function c(e,r){const n=e.toLocaleLowerCase().replace(/[^a-z0-9]/g,"_").replace(/_+/g,"_");return r?n:n.replace(/_$/,"")}export{s as c,c as n};
//# sourceMappingURL=string.2d6559bb.js.map
