import"./outputWidgets.8be138ba.js";import{M as r}from"./Title.12e8916a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="f7d36bca-d8e6-4149-9e4f-dadacb022ee5",e._sentryDebugIdIdentifier="sentry-dbid-f7d36bca-d8e6-4149-9e4f-dadacb022ee5")}catch{}})();function o(e){switch(typeof e){case"object":return Object.entries(e).map(([t,n])=>({title:t,key:t,children:o(n)}));default:return[{title:e,key:e}]}}function f(e){return new Promise(t=>{r.confirm({title:e,onOk:()=>t(!0),onCancel:()=>t(!1)})})}export{f as a,o as t};
//# sourceMappingURL=ant-design.e9f581dc.js.map
