import{R as d}from"./Title.12e8916a.js";import{E as n}from"./outputWidgets.8be138ba.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="788e4de5-b8a3-4025-9526-596aacc6d776",e._sentryDebugIdIdentifier="sentry-dbid-788e4de5-b8a3-4025-9526-596aacc6d776")}catch{}})();const a=n(d);export{a as A};
//# sourceMappingURL=index.bc7e7ec9.js.map
