import{v as t,b as s,et as o}from"./outputWidgets.8be138ba.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="fa310fb9-61ac-4d48-8db7-173ff26ee638",e._sentryDebugIdIdentifier="sentry-dbid-fa310fb9-61ac-4d48-8db7-173ff26ee638")}catch{}})();const r={},a={class:"organization-settings"};function d(e,n){return s(),o("div",a,"Organization settings")}const c=t(r,[["render",d]]);export{c as default};
//# sourceMappingURL=OrganizationSettings.86791551.js.map
