import{cC as n}from"./outputWidgets.8be138ba.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="b057956a-23ed-49bb-a2b7-06e57b530595",e._sentryDebugIdIdentifier="sentry-dbid-b057956a-23ed-49bb-a2b7-06e57b530595")}catch{}})();const b=(e,r)=>{n.error({message:e,description:r})};export{b as p};
//# sourceMappingURL=popupNotifcation.5544b2c7.js.map
