import{S as p}from"./Sidebar.44f5eb77.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.43399a7a.js";import{G as l,H as b,I as u}from"./icons.35976e57.js";import{d,ez as f,H as g,a as _,b as y,c as v,w as t,f as r}from"./outputWidgets.8be138ba.js";import{a as w}from"./asyncComputed.96c9ad3b.js";import"./router.bb47648a.js";import{O as z}from"./organization.f7d7229f.js";import"./columns.5510282a.js";import{B as h}from"./BaseLayout.7e0231be.js";import"./Tooltip.94183daf.js";import"./logo.084e5d7c.js";import"./index.98827a3d.js";import"./Title.12e8916a.js";import"./index.568a8efe.js";import"./index.7e655723.js";import"./index.0df733bd.js";import"./gateway.93fa1934.js";import"./activeRecord.f6cce158.js";import"./pubsub.e324f67c.js";import"./index.f4ac7424.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="7cf68c47-5e26-4a5b-8fbb-70078659150b",o._sentryDebugIdIdentifier="sentry-dbid-7cf68c47-5e26-4a5b-8fbb-70078659150b")}catch{}})();const J=d({__name:"Organization",setup(o){const n=f().params.organizationId,{result:a}=w(()=>z.get(n)),i=g(()=>a.value?[{label:"My organizations",path:"/organizations"},{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:l,path:"projects"},{name:"Members",icon:b,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:t(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(p,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{J as default};
//# sourceMappingURL=Organization.ca6ee8e3.js.map
