import{V as s}from"./outputWidgets.8be138ba.js";import{c as i,d as a}from"./index.c72b88ec.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="39f26ec9-b7dd-4f86-809e-887898c83d30",e._sentryDebugIdIdentifier="sentry-dbid-39f26ec9-b7dd-4f86-809e-887898c83d30")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:f,TimePicker:m,QuarterPicker:o,RangePicker:c}=i(a),b=s(n,{WeekPicker:r,MonthPicker:t,YearPicker:f,RangePicker:c,TimePicker:m,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(c.name,c),e.component(t.name,t),e.component(r.name,r),e.component(o.name,o),e)});export{b as D,t as M,o as Q,c as R,r as W};
//# sourceMappingURL=dayjs.8991d429.js.map
