import"./outputWidgets.8be138ba.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="58810253-35c6-42d6-8b76-ec036cdb2dde",x._sentryDebugIdIdentifier="sentry-dbid-58810253-35c6-42d6-8b76-ec036cdb2dde")}catch{}})();const t=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)}),r=()=>Math.random().toString(36).slice(2);export{r,t as u};
//# sourceMappingURL=uuid.3f13542a.js.map
